<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Život existuje i mimo prohlížeč!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Toto je vývojová verze, neočekávejte plnou funkčnost.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Hlaste chyby a posílejte své nápady na %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je svobodný software, ale jeho vývoj stojí drahocenný čas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Prosím &lt;a href=&apos;%1&apos;&gt;přispějte přes PayPal&lt;/a&gt; a podpořte další vývoj aplikace %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="26"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Prosím &lt;a href=&apos;%1&apos;&gt;přispějte&lt;/a&gt; na další vývoj %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="33"/>
        <source>Icon designed by %1.</source>
        <translation>Autor ikony: %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>Autor kompaktního módu: %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="35"/>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Autor podpory HTTP proxy: %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Verzi pro Windows sestavil: %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="38"/>
        <source>Translated by %1</source>
        <translation>Přeložili: %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="65"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Vydáno pod &lt;a href=&apos;%1&apos;&gt;licencí GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="77"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Co jste vždy chtěli vědět o aplikaci %1 ale nikdy jste se neodvážili zeptat</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Odstranit vše</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="../src/downloaditem.cpp" line="214"/>
        <source>bytes</source>
        <translation>bajtů</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="217"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="220"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="236"/>
        <source>bytes/sec</source>
        <translation>bajtů/sec</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="239"/>
        <source>KB/sec</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="242"/>
        <source>MB/sec</source>
        <translation>MB/se</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="248"/>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="251"/>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="254"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 zbývá</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Toto je pouze demoverze %1.</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Umí stahovat pouze videa délky do %1 minut, abyste mohli funkci stahování vyzkoušet</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="53"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="54"/>
        <source>Get the full version</source>
        <translation>Získat plnou verzi</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="126"/>
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n stahování</numerusform>
            <numerusform>%n stahování</numerusform>
            <numerusform>%n stahování</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="../src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Změnit složku pro stahování...</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Vyberte složku, do které se bude stahovat</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Nastavení složky pro stahování bylo změněno.</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Probíhající stahování budou stále pokračovat v ukládání do dříve nastaveného adresáře</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Stahováno do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="../src/downloadview.cpp" line="18"/>
        <location filename="../src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Pustit/Pozastavit</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Zastavit přehrávání po dokončení nyní přehrávaného videa</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Další video</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Předchozí video</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Zvýšit hlasitost</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Snížit hlasitost</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Ztlumit hlasitost</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Rychle vpřed</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Rychle vzad</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="46"/>
        <source>Searching...</source>
        <translation>Hledám...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Show %1 More</source>
        <translation>Zobrazit dalších %1</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>No videos</source>
        <translation>Žádná videa</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No more videos</source>
        <translation>Žádná další videa</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="66"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Zpět</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Vrátit se k předchozí obrazovce</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="102"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="103"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Zastaví přehrávání a vrátí se zpět na vyhledávání</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="109"/>
        <source>S&amp;kip</source>
        <translation>Př&amp;eskočit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="110"/>
        <source>Skip to the next video</source>
        <translation>Přeskočí na další video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="116"/>
        <location filename="../src/MainWindow.cpp" line="625"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="117"/>
        <location filename="../src/MainWindow.cpp" line="626"/>
        <source>Pause playback</source>
        <translation>Pozastaví přehrávání</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="123"/>
        <location filename="../src/MainWindow.cpp" line="709"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="124"/>
        <source>Go full screen</source>
        <translation>Přepne na celou obrazovku</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="133"/>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompaktní mód</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="134"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skryje playlist a toolbar</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Otevřít video na YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="142"/>
        <source>Open the &amp;YouTube page</source>
        <translation>Otevřít stránku &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="143"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Otevře video na webu YouTube a pozastaví přehrávání</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="149"/>
        <source>Copy the YouTube &amp;link</source>
        <translation>Zkopírovat &amp;odkaz na YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="150"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Zkopíruje adresu videa na YouTube do schránky</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="156"/>
        <source>Copy the video stream &amp;URL</source>
        <translation>Zkopírovat adresu &amp;video streamu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="157"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Zkopíruje do schránky adresu video streamu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="163"/>
        <source>&amp;Remove</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="164"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Odstraní vybraná videa z playlistu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="170"/>
        <source>Move &amp;Up</source>
        <translation>&amp;Nahoru</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="171"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Posune vybraná videa výš v playlistu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="177"/>
        <source>Move &amp;Down</source>
        <translation>&amp;Dolů</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="178"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Posune vybraná videa níž v playlistu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="184"/>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Vymazat hledané výrazy</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="189"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Vyprázdní historii vyhledávání. Akci nelze vrátit.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="194"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="196"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>Bye</source>
        <translation>Sbohem</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="201"/>
        <source>&amp;Website</source>
        <translation>&amp;Homepage</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="203"/>
        <source>%1 on the Web</source>
        <translation>%1 na Webu</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="207"/>
        <source>Make a &amp;donation</source>
        <translation>&amp;Podpořit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="274"/>
        <location filename="../src/MainWindow.cpp" line="932"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Stahování</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="275"/>
        <source>Show details about video downloads</source>
        <translation>Zobrazit podrobnosti o stahování videí</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="283"/>
        <source>&amp;Download</source>
        <translation>&amp;Stáhnout</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="284"/>
        <source>Download the current video</source>
        <translation>Stáhnout přávě zobrazené video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="576"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Chcete ukončit %1, přestože ještě probíhá stahování?</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="577"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jestli nyní ukončíte %1, bude nedokončené stahování přerušeno</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="580"/>
        <source>Close and cancel download</source>
        <translation>Přerušit stahování a ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="581"/>
        <source>Wait for download to finish</source>
        <translation>Počkat na dokončení stahování</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="877"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maximální rozlišení videa je %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="933"/>
        <source>Downloads complete</source>
        <translation>Všechna stahování byla dokončena</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Podpořte přes PayPal</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="208"/>
        <source>Please support the continued development of %1</source>
        <translation>Prosím přispějte na další vývoj aplikace %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="212"/>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="214"/>
        <source>Info about %1</source>
        <translation>Info o aplikaci %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="222"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="241"/>
        <source>Mute volume</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="243"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">HD video je povolené</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">HD video není povolené</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Aktuální video je v HD</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Aktuální video není v HD</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="917"/>
        <source>Your privacy is now safe</source>
        <translation>Vaše soukromí je nyní v bezpečí</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="325"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplikace</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="333"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="340"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="359"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="418"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Stiskněte %1 pro zvýšení hlasitosti; %2 pro snížení</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="557"/>
        <location filename="../src/MainWindow.cpp" line="563"/>
        <source>Opening %1</source>
        <translation>Otevírám %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="616"/>
        <source>Fatal error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="618"/>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="641"/>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="642"/>
        <source>Resume playback</source>
        <translation>Pokračovat v přehrávání</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="732"/>
        <source>Exit &amp;Full Screen</source>
        <translation>Vypnout &amp;fullscreen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="815"/>
        <source>Remaining time: %1</source>
        <translation>Zbývající čas: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="861"/>
        <source>Volume at %1%</source>
        <translation>Hlasitost na %1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="867"/>
        <source>Volume is muted</source>
        <translation>Zvuk je ztlumen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="870"/>
        <source>Volume is unmuted</source>
        <translation>Zvuk je zapnut</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="26"/>
        <source>Most relevant</source>
        <translation>Nalezená videa</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="33"/>
        <source>Most recent</source>
        <translation>Nejnovější</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="40"/>
        <source>Most viewed</source>
        <translation>Nejsledovanější</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="360"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Nyní můžete vložit odkaz na video na YouTube do jiného programu</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="368"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Nyní můžete vložit odkaz na video stream do jiné aplikace</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="369"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Tento odkaz platí jen po omezenou dobu.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="465"/>
        <source>This is just the demo version of %1.</source>
        <translation>Toto je %1 -- demoverze.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="466"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Umožňuje vyzkoušet aplikaci, abyste ověřili, jestli pro vás funguje.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="469"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="470"/>
        <source>Get the full version</source>
        <translation>Stáhnout plnou verzi</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="495"/>
        <source>Downloading %1</source>
        <translation>Je stahováno %1</translation>
    </message>
    <message>
        <location filename="../src/MediaView.h" line="36"/>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Sledujete &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="192"/>
        <source>Network error: %1</source>
        <translation>Chyba připojení: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="150"/>
        <source>%1 views</source>
        <translation>Shlédnuto %1x</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="266"/>
        <source>%1 of %2 (%3) ? %4</source>
        <translation>1 z %2 (%3) ? %4</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="273"/>
        <source>Preparing</source>
        <translation>Připravuje se</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="275"/>
        <source>Failed</source>
        <translation>Selhalo</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="277"/>
        <source>Completed</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="279"/>
        <source>Stopped</source>
        <translation>Zastaveno</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="315"/>
        <source>Stop downloading</source>
        <translation>Zastavit stahování</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="325"/>
        <source>Show in %1</source>
        <translation>Ukázat v %1</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="327"/>
        <source>Open parent folder</source>
        <translation>Otevřít příslušný adresář</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="336"/>
        <source>Restart downloading</source>
        <translation>Začít stahovat znova</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="50"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Vítejte v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="60"/>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Zadejte klíčové slovo pro vyhledávání videí.</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="80"/>
        <source>Watch</source>
        <translation>Sledovat</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="97"/>
        <source>Recent keywords</source>
        <translation>Poslední klíčová slova</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="199"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nová verze aplikace %1 je dostupná. Prosím &lt;a href=&apos;%2&apos;&gt;aktualizujte na verzi %3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="29"/>
        <source>Make yourself comfortable</source>
        <translation>Udělejte si pohodlí</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Nastavení</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">&amp;Nastavení videa</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Zobrazit video ve vysoké kvalitě pokud je dostupná</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">&amp;Uložit hledané výrazy</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;Vymazat hledané výrazy</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="173"/>
        <source>Network error: %1 for %2</source>
        <translation>Chyba přípojení: %1 pro %2</translation>
    </message>
</context>
</TS>
